summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJaime <jaime.frio@gmail.com>2017-05-09 11:46:35 +0200
committerGitHub <noreply@github.com>2017-05-09 11:46:35 +0200
commitc11628abd820a1f44b052ea87af810f8f00cf2e4 (patch)
tree1b604adcf75bec0009c27d340e6ede2adb03b2ec
parent23b0cf3a5925dbc1f0503fbdacdf8088372f4ab5 (diff)
parentef5684564e3074daf614846f30bfdd7f15f5254f (diff)
downloadpython-numpy-c11628abd820a1f44b052ea87af810f8f00cf2e4.tar.gz
python-numpy-c11628abd820a1f44b052ea87af810f8f00cf2e4.tar.bz2
python-numpy-c11628abd820a1f44b052ea87af810f8f00cf2e4.zip
Merge pull request #9075 from scop/spelling
ENH: Spelling fixes
-rw-r--r--doc/Py3K.rst.txt2
-rw-r--r--doc/cdoc/Doxyfile2
-rw-r--r--doc/f2py/HISTORY.txt2
-rw-r--r--doc/f2py/apps.tex2
-rw-r--r--doc/f2py/multiarray/fortran_array_from_pyobj.txt2
-rw-r--r--doc/f2py/multiarray/transpose.txt2
-rw-r--r--doc/f2py/multiarrays.txt2
-rw-r--r--doc/release/1.13.0-notes.rst2
-rw-r--r--doc/source/f2py/signature-file.rst2
-rw-r--r--doc/source/reference/arrays.dtypes.rst2
-rw-r--r--doc/source/reference/c-api.ufunc.rst2
-rw-r--r--doc/source/reference/ufuncs.rst2
-rw-r--r--doc/source/user/numpy-for-matlab-users.rst2
-rw-r--r--numpy/core/_internal.py2
-rw-r--r--numpy/core/einsumfunc.py6
-rw-r--r--numpy/core/include/numpy/ufuncobject.h2
-rw-r--r--numpy/core/machar.py2
-rw-r--r--numpy/core/src/multiarray/convert_datatype.c2
-rw-r--r--numpy/core/src/multiarray/ctors.c2
-rw-r--r--numpy/core/src/multiarray/datetime_busdaycal.c2
-rw-r--r--numpy/core/src/multiarray/getset.c2
-rw-r--r--numpy/core/src/multiarray/hashdescr.c2
-rw-r--r--numpy/core/src/multiarray/iterators.c2
-rw-r--r--numpy/core/src/multiarray/mapping.c2
-rw-r--r--numpy/core/src/multiarray/multiarraymodule.c2
-rw-r--r--numpy/core/src/multiarray/shape.c2
-rw-r--r--numpy/core/src/private/lowlevel_strided_loops.h4
-rw-r--r--numpy/core/src/umath/ufunc_object.c2
-rw-r--r--numpy/core/tests/test_einsum.py2
-rw-r--r--numpy/core/tests/test_multiarray.py2
-rw-r--r--numpy/core/tests/test_nditer.py2
-rw-r--r--numpy/f2py/src/fortranobject.c2
-rw-r--r--numpy/lib/_datasource.py2
-rw-r--r--numpy/lib/function_base.py2
-rw-r--r--numpy/lib/index_tricks.py2
-rw-r--r--numpy/lib/info.py2
-rw-r--r--numpy/lib/shape_base.py2
-rw-r--r--numpy/lib/tests/test_function_base.py4
-rw-r--r--numpy/lib/tests/test_stride_tricks.py2
-rw-r--r--numpy/lib/utils.py2
-rw-r--r--numpy/linalg/umath_linalg.c.src2
-rw-r--r--numpy/ma/core.py6
-rw-r--r--numpy/ma/extras.py8
-rw-r--r--numpy/ma/tests/test_core.py2
-rw-r--r--numpy/ma/tests/test_deprecations.py2
-rw-r--r--numpy/polynomial/legendre.py2
-rw-r--r--numpy/testing/tests/test_decorators.py4
-rw-r--r--numpy/tests/test_warnings.py4
-rw-r--r--pavement.py2
49 files changed, 60 insertions, 60 deletions
diff --git a/doc/Py3K.rst.txt b/doc/Py3K.rst.txt
index 7150430ac..44111eeb5 100644
--- a/doc/Py3K.rst.txt
+++ b/doc/Py3K.rst.txt
@@ -721,7 +721,7 @@ keep in mind.
warnings if they are initialized in the old way.
2) The compare slot has been made reserved in order to preserve binary
- compatibily while the tp_compare function went away. The tp_richcompare
+ compatibility while the tp_compare function went away. The tp_richcompare
function has replaced it and we need to use that slot instead. This will
likely require modifications in the searchsorted functions and generic sorts
that currently use the compare function.
diff --git a/doc/cdoc/Doxyfile b/doc/cdoc/Doxyfile
index e8cceb223..9f702724d 100644
--- a/doc/cdoc/Doxyfile
+++ b/doc/cdoc/Doxyfile
@@ -292,7 +292,7 @@ TYPEDEF_HIDES_STRUCT = NO
# causing a significant performance penality.
# If the system has enough physical memory increasing the cache will improve the
# performance by keeping more symbols in memory. Note that the value works on
-# a logarithmic scale so increasing the size by one will rougly double the
+# a logarithmic scale so increasing the size by one will roughly double the
# memory usage. The cache size is given by this formula:
# 2^(16+SYMBOL_CACHE_SIZE). The valid range is 0..9, the default is 0,
# corresponding to a cache size of 2^16 = 65536 symbols
diff --git a/doc/f2py/HISTORY.txt b/doc/f2py/HISTORY.txt
index 5ab09ae1a..44dc8b916 100644
--- a/doc/f2py/HISTORY.txt
+++ b/doc/f2py/HISTORY.txt
@@ -601,7 +601,7 @@ Public Release 2.32.225-1419
- "From sky" program group is created only if ``groupcounter<1``.
See TODO.txt.
- Added support for ``dimension(n:*)``, ``dimension(*:n)``. They are
- treated as ``dimesnion(*)`` by f2py.
+ treated as ``dimension(*)`` by f2py.
- Fixed parameter substitution (this fixes TODO item by Patrick
LeGresley, 22 Aug 2001).
diff --git a/doc/f2py/apps.tex b/doc/f2py/apps.tex
index 513c048bd..bd88d09bf 100644
--- a/doc/f2py/apps.tex
+++ b/doc/f2py/apps.tex
@@ -23,7 +23,7 @@ extern void dfftw_one(fftw_complex *in,fftw_complex *out,int *n) {
fftw_destroy_plan(p);
}
\end{verbatim}
-and here follows the corresponding siganture file (created manually):
+and here follows the corresponding signature file (created manually):
\begin{verbatim}
!%f90
! File: fftw.f90
diff --git a/doc/f2py/multiarray/fortran_array_from_pyobj.txt b/doc/f2py/multiarray/fortran_array_from_pyobj.txt
index e0f383fbd..c7ca2d582 100644
--- a/doc/f2py/multiarray/fortran_array_from_pyobj.txt
+++ b/doc/f2py/multiarray/fortran_array_from_pyobj.txt
@@ -157,7 +157,7 @@ Main goal:
==========
Our goal is to generate Python C/API functions py_fun and py_cun such
-that their usage in Python would be identical. The cruical part of
+that their usage in Python would be identical. The crucial part of
their implementation are in functions that take a PyObject and
return a PyArrayObject such that it is contiguous and its data pointer
is suitable for passing on to the arguments of C or Fortran functions.
diff --git a/doc/f2py/multiarray/transpose.txt b/doc/f2py/multiarray/transpose.txt
index 925e7a399..b04152418 100644
--- a/doc/f2py/multiarray/transpose.txt
+++ b/doc/f2py/multiarray/transpose.txt
@@ -179,7 +179,7 @@ Times are in seconds, for a 900*904 matrix:
380 NAG 467 disc copy
1.03 1.14 .391 .177
-Compare two vector algortihms, one I wrote and the second a matrix
+Compare two vector algorithms, one I wrote and the second a matrix
copy:
My Alg Matrix copy
diff --git a/doc/f2py/multiarrays.txt b/doc/f2py/multiarrays.txt
index 75aeaab9a..a4bd72cb5 100644
--- a/doc/f2py/multiarrays.txt
+++ b/doc/f2py/multiarrays.txt
@@ -81,7 +81,7 @@ so that the checks can be performed in the proper order.
effect but they are not so safe and I will not discuss about them here).
Hint: If the array a should be a work array (as used frequently in
-Fortran) and you a too lazy (its good lazyness;) to provide it (in Python)
+Fortran) and you a too lazy (its good laziness;) to provide it (in Python)
then you can define it as optional by ediding the signature:
subroutine foo(l,m,n,a)
integer :: l
diff --git a/doc/release/1.13.0-notes.rst b/doc/release/1.13.0-notes.rst
index 45e9a2e9b..9dea7086a 100644
--- a/doc/release/1.13.0-notes.rst
+++ b/doc/release/1.13.0-notes.rst
@@ -268,7 +268,7 @@ versions.
NumPy may be built with relaxed stride checking debugging
---------------------------------------------------------
-Setting NPY_RELAXED_STRIDES_DEBUG=1 in the enviroment when relaxed stride
+Setting NPY_RELAXED_STRIDES_DEBUG=1 in the environment when relaxed stride
checking is enabled will cause NumPy to be compiled with the affected strides
set to the maximum value of npy_intp in order to help detect invalid usage of
the strides in downstream projects. When enabled, invalid usage often results
diff --git a/doc/source/f2py/signature-file.rst b/doc/source/f2py/signature-file.rst
index 090a5eca5..bd926f33c 100644
--- a/doc/source/f2py/signature-file.rst
+++ b/doc/source/f2py/signature-file.rst
@@ -284,7 +284,7 @@ Other statements:
module`` block then the second multiline block is inserted
after the definition of external routines.
- When used inside ``<routine singature>``, then given C code will
+ When used inside ``<routine signature>``, then given C code will
be inserted to the corresponding wrapper function just after
declaring variables but before any C statements. So, ``usercode``
follow-up can contain both declarations and C statements.
diff --git a/doc/source/reference/arrays.dtypes.rst b/doc/source/reference/arrays.dtypes.rst
index 031fb6529..dcf04b453 100644
--- a/doc/source/reference/arrays.dtypes.rst
+++ b/doc/source/reference/arrays.dtypes.rst
@@ -186,7 +186,7 @@ Built-in Python types
================ ===============
Note that ``str`` refers to either null terminated bytes or unicode strings
- depending on the Python version. In code targetting both Python 2 and 3
+ depending on the Python version. In code targeting both Python 2 and 3
``np.unicode_`` should be used as a dtype for strings.
See :ref:`Note on string types<string-dtype-note>`.
diff --git a/doc/source/reference/c-api.ufunc.rst b/doc/source/reference/c-api.ufunc.rst
index b5e8b92d7..79ad256f5 100644
--- a/doc/source/reference/c-api.ufunc.rst
+++ b/doc/source/reference/c-api.ufunc.rst
@@ -200,7 +200,7 @@ Functions
or :c:data:`Py_None`. The callable object will only be used if
:c:data:`UFUNC_ERR_CALL` is set as the desired error checking
method. This routine manages the GIL and is safe to call even
- after releasing the GIL. If an error in the IEEE-compatibile
+ after releasing the GIL. If an error in the IEEE-compatible
hardware is determined a -1 is returned, otherwise a 0 is
returned.
diff --git a/doc/source/reference/ufuncs.rst b/doc/source/reference/ufuncs.rst
index e82571f6c..34ad36a0b 100644
--- a/doc/source/reference/ufuncs.rst
+++ b/doc/source/reference/ufuncs.rst
@@ -177,7 +177,7 @@ Casting Rules
.. note::
In NumPy 1.6.0, a type promotion API was created to encapsulate the
- mechansim for determining output types. See the functions
+ mechanism for determining output types. See the functions
:func:`result_type`, :func:`promote_types`, and
:func:`min_scalar_type` for more details.
diff --git a/doc/source/user/numpy-for-matlab-users.rst b/doc/source/user/numpy-for-matlab-users.rst
index 2661c79c3..7f48e7031 100644
--- a/doc/source/user/numpy-for-matlab-users.rst
+++ b/doc/source/user/numpy-for-matlab-users.rst
@@ -162,7 +162,7 @@ There are pros and cons to using both:
- ``:)`` ``A*B`` is matrix multiplication, so more convenient for
linear algebra.
- ``<:(`` Element-wise multiplication requires calling a function,
- ``multipy(A,B)``.
+ ``multiply(A,B)``.
- ``<:(`` The use of operator overloading is a bit illogical: ``*``
does not work elementwise but ``/`` does.
diff --git a/numpy/core/_internal.py b/numpy/core/_internal.py
index d8d9168ac..f2f24bcc5 100644
--- a/numpy/core/_internal.py
+++ b/numpy/core/_internal.py
@@ -132,7 +132,7 @@ def _array_descr(descriptor):
# Note that the name numpy.core._internal._reconstruct is embedded in
# pickles of ndarrays made with NumPy before release 1.0
# so don't remove the name here, or you'll
-# break backward compatibilty.
+# break backward compatibility.
def _reconstruct(subtype, shape, dtype):
return ndarray.__new__(subtype, shape, dtype)
diff --git a/numpy/core/einsumfunc.py b/numpy/core/einsumfunc.py
index c54a4a263..e242363a4 100644
--- a/numpy/core/einsumfunc.py
+++ b/numpy/core/einsumfunc.py
@@ -46,7 +46,7 @@ def _find_contraction(positions, input_sets, output_set):
"""
Finds the contraction for a given set of input and output sets.
- Paramaters
+ Parameters
----------
positions : iterable
Integer positions of terms used in the contraction.
@@ -108,7 +108,7 @@ def _optimal_path(input_sets, output_set, idx_dict, memory_limit):
on ``memory_limit`` and returns the lowest cost path. This algorithm
scales factorial with respect to the elements in the list ``input_sets``.
- Paramaters
+ Parameters
----------
input_sets : list
List of sets that represent the lhs side of the einsum subscript
@@ -187,7 +187,7 @@ def _greedy_path(input_sets, output_set, idx_dict, memory_limit):
``memory_limit``. This algorithm scales cubically with respect to the
number of elements in the list ``input_sets``.
- Paramaters
+ Parameters
----------
input_sets : list
List of sets that represent the lhs side of the einsum subscript
diff --git a/numpy/core/include/numpy/ufuncobject.h b/numpy/core/include/numpy/ufuncobject.h
index e03a7a4a5..d0ac1fd7d 100644
--- a/numpy/core/include/numpy/ufuncobject.h
+++ b/numpy/core/include/numpy/ufuncobject.h
@@ -78,7 +78,7 @@ typedef int (PyUFunc_TypeResolutionFunc)(
*
* ufunc: The ufunc object.
* dtypes: An array which has been populated with dtypes,
- * in most cases by the type resolution funciton
+ * in most cases by the type resolution function
* for the same ufunc.
* fixed_strides: For each input/output, either the stride that
* will be used every time the function is called
diff --git a/numpy/core/machar.py b/numpy/core/machar.py
index 6f2735d32..7578544fe 100644
--- a/numpy/core/machar.py
+++ b/numpy/core/machar.py
@@ -30,7 +30,7 @@ class MachAr(object):
eps : float
Floating-point number ``beta**machep`` (floating point precision)
negep : int
- Exponent of the smallest power of `ibeta` that, substracted
+ Exponent of the smallest power of `ibeta` that, subtracted
from 1.0, gives something different from 1.0.
epsneg : float
Floating-point number ``beta**negep``.
diff --git a/numpy/core/src/multiarray/convert_datatype.c b/numpy/core/src/multiarray/convert_datatype.c
index e5983340c..e495f3160 100644
--- a/numpy/core/src/multiarray/convert_datatype.c
+++ b/numpy/core/src/multiarray/convert_datatype.c
@@ -1530,7 +1530,7 @@ static int min_scalar_type_num(char *valueptr, int type_num,
}
/*
* The code to demote complex to float is disabled for now,
- * as forcing complex by adding 0j is probably desireable.
+ * as forcing complex by adding 0j is probably desirable.
*/
case NPY_CFLOAT: {
/*
diff --git a/numpy/core/src/multiarray/ctors.c b/numpy/core/src/multiarray/ctors.c
index f7a5f3deb..829bffcbd 100644
--- a/numpy/core/src/multiarray/ctors.c
+++ b/numpy/core/src/multiarray/ctors.c
@@ -280,7 +280,7 @@ _update_descr_and_dimensions(PyArray_Descr **des, npy_intp *newdims,
npy_intp *mystrides;
mystrides = newstrides + oldnd;
- /* Make new strides -- alwasy C-contiguous */
+ /* Make new strides -- always C-contiguous */
tempsize = (*des)->elsize;
for (i = numnew - 1; i >= 0; i--) {
mystrides[i] = tempsize;
diff --git a/numpy/core/src/multiarray/datetime_busdaycal.c b/numpy/core/src/multiarray/datetime_busdaycal.c
index b0c53b362..7eaf0cd7a 100644
--- a/numpy/core/src/multiarray/datetime_busdaycal.c
+++ b/numpy/core/src/multiarray/datetime_busdaycal.c
@@ -234,7 +234,7 @@ normalize_holidays_list(npy_holidayslist *holidays, npy_bool *weekmask)
/* Sort the dates */
qsort(dates, count, sizeof(npy_datetime), &qsort_datetime_compare);
- /* Sweep throught the array, eliminating unnecessary values */
+ /* Sweep through the array, eliminating unnecessary values */
trimcount = 0;
for (i = 0; i < count; ++i) {
npy_datetime date = dates[i];
diff --git a/numpy/core/src/multiarray/getset.c b/numpy/core/src/multiarray/getset.c
index 2fbf15848..3ed1666ae 100644
--- a/numpy/core/src/multiarray/getset.c
+++ b/numpy/core/src/multiarray/getset.c
@@ -429,7 +429,7 @@ array_nbytes_get(PyArrayObject *self)
* Also needing change: strides, itemsize
*
* Either itemsize is exactly the same or the array is single-segment
- * (contiguous or fortran) with compatibile dimensions The shape and strides
+ * (contiguous or fortran) with compatible dimensions The shape and strides
* will be adjusted in that case as well.
*/
static int
diff --git a/numpy/core/src/multiarray/hashdescr.c b/numpy/core/src/multiarray/hashdescr.c
index 6ed4f7905..8465093b9 100644
--- a/numpy/core/src/multiarray/hashdescr.c
+++ b/numpy/core/src/multiarray/hashdescr.c
@@ -253,7 +253,7 @@ static int _array_descr_walk(PyArray_Descr* descr, PyObject *l)
}
/*
- * Return 0 if successfull
+ * Return 0 if successful
*/
static int _PyArray_DescrHashImp(PyArray_Descr *descr, npy_hash_t *hash)
{
diff --git a/numpy/core/src/multiarray/iterators.c b/numpy/core/src/multiarray/iterators.c
index 8df555fa1..01910a657 100644
--- a/numpy/core/src/multiarray/iterators.c
+++ b/numpy/core/src/multiarray/iterators.c
@@ -911,7 +911,7 @@ iter_ass_subscript(PyArrayIterObject *self, PyObject *ind, PyObject *val)
type = PyArray_DESCR(self->ao);
/*
- * Check for Boolean -- this is first becasue
+ * Check for Boolean -- this is first because
* Bool is a subclass of Int
*/
if (PyBool_Check(ind)) {
diff --git a/numpy/core/src/multiarray/mapping.c b/numpy/core/src/multiarray/mapping.c
index 302b0ca1c..6c300a2bf 100644
--- a/numpy/core/src/multiarray/mapping.c
+++ b/numpy/core/src/multiarray/mapping.c
@@ -3305,7 +3305,7 @@ arraymapiter_dealloc(PyArrayMapIterObject *mit)
* The mapiter object must be created new each time. It does not work
* to bind to a new array, and continue.
*
- * This was the orginal intention, but currently that does not work.
+ * This was the original intention, but currently that does not work.
* Do not expose the MapIter_Type to Python.
*
* The original mapiter(indexobj); mapiter.bind(a); idea is now fully
diff --git a/numpy/core/src/multiarray/multiarraymodule.c b/numpy/core/src/multiarray/multiarraymodule.c
index b6b134f2d..2c5849dc0 100644
--- a/numpy/core/src/multiarray/multiarraymodule.c
+++ b/numpy/core/src/multiarray/multiarraymodule.c
@@ -3557,7 +3557,7 @@ compare_chararrays(PyObject *NPY_UNUSED(dummy), PyObject *args, PyObject *kwds)
char *cmp_str;
Py_ssize_t strlength;
PyObject *res = NULL;
- static char msg[] = "comparision must be '==', '!=', '<', '>', '<=', '>='";
+ static char msg[] = "comparison must be '==', '!=', '<', '>', '<=', '>='";
static char *kwlist[] = {"a1", "a2", "cmp", "rstrip", NULL};
if (!PyArg_ParseTupleAndKeywords(args, kwds, "OOs#O&:compare_chararrays",
diff --git a/numpy/core/src/multiarray/shape.c b/numpy/core/src/multiarray/shape.c
index a5960044e..b32b67146 100644
--- a/numpy/core/src/multiarray/shape.c
+++ b/numpy/core/src/multiarray/shape.c
@@ -294,7 +294,7 @@ PyArray_Newshape(PyArrayObject *self, PyArray_Dims *newdims,
-/* For back-ward compatability -- Not recommended */
+/* For backward compatibility -- Not recommended */
/*NUMPY_API
* Reshape
diff --git a/numpy/core/src/private/lowlevel_strided_loops.h b/numpy/core/src/private/lowlevel_strided_loops.h
index f66de14b5..e785c6796 100644
--- a/numpy/core/src/private/lowlevel_strided_loops.h
+++ b/numpy/core/src/private/lowlevel_strided_loops.h
@@ -214,7 +214,7 @@ PyArray_GetDTypeTransferFunction(int aligned,
/*
* This is identical to PyArray_GetDTypeTransferFunction, but returns a
* transfer function which also takes a mask as a parameter. The mask is used
- * to determine which values to copy, and data is transfered exactly when
+ * to determine which values to copy, and data is transferred exactly when
* mask[i*mask_stride] is true.
*
* If move_references is true, values which are not copied to the
@@ -286,7 +286,7 @@ PyArray_CastRawArrays(npy_intp count,
* count:
* How many elements to transfer
* src_itemsize:
- * How big each element is. If transfering between elements of different
+ * How big each element is. If transferring between elements of different
* sizes, for example a casting operation, the 'stransfer' function
* should be specialized for that, in which case 'stransfer' will use
* this parameter as the source item size.
diff --git a/numpy/core/src/umath/ufunc_object.c b/numpy/core/src/umath/ufunc_object.c
index 9b51969cb..3a6c8e297 100644
--- a/numpy/core/src/umath/ufunc_object.c
+++ b/numpy/core/src/umath/ufunc_object.c
@@ -223,7 +223,7 @@ PyUFunc_handlefperr(int errmask, PyObject *errobj, int retstatus, int *first)
NPY_NO_EXPORT int
PyUFunc_checkfperr(int errmask, PyObject *errobj, int *first)
{
- /* clearing is done for backward compatiblity */
+ /* clearing is done for backward compatibility */
int retstatus = npy_clear_floatstatus();
return PyUFunc_handlefperr(errmask, errobj, retstatus, first);
diff --git a/numpy/core/tests/test_einsum.py b/numpy/core/tests/test_einsum.py
index 3ecc829f4..8466d924e 100644
--- a/numpy/core/tests/test_einsum.py
+++ b/numpy/core/tests/test_einsum.py
@@ -643,7 +643,7 @@ class TestEinSum(TestCase):
def test_einsum_fixed_collapsingbug(self):
# Issue #5147.
- # The bug only occured when output argument of einssum was used.
+ # The bug only occurred when output argument of einssum was used.
x = np.random.normal(0, 1, (5, 5, 5, 5))
y1 = np.zeros((5, 5))
np.einsum('aabb->ab', x, out=y1)
diff --git a/numpy/core/tests/test_multiarray.py b/numpy/core/tests/test_multiarray.py
index 97d801731..745c6ca5c 100644
--- a/numpy/core/tests/test_multiarray.py
+++ b/numpy/core/tests/test_multiarray.py
@@ -4270,7 +4270,7 @@ class TestResize(TestCase):
x.resize()
assert_array_equal(x, np.eye(3))
- def test_invalid_arguements(self):
+ def test_invalid_arguments(self):
self.assertRaises(TypeError, np.eye(3).resize, 'hi')
self.assertRaises(ValueError, np.eye(3).resize, -1)
self.assertRaises(TypeError, np.eye(3).resize, order=1)
diff --git a/numpy/core/tests/test_nditer.py b/numpy/core/tests/test_nditer.py
index 2e37fc5da..77521317e 100644
--- a/numpy/core/tests/test_nditer.py
+++ b/numpy/core/tests/test_nditer.py
@@ -1386,7 +1386,7 @@ def test_iter_allocate_output_itorder():
assert_equal(i.operands[1].dtype, np.dtype('f4'))
def test_iter_allocate_output_opaxes():
- # Specifing op_axes should work
+ # Specifying op_axes should work
a = arange(24, dtype='i4').reshape(2, 3, 4)
i = nditer([None, a], [], [['writeonly', 'allocate'], ['readonly']],
diff --git a/numpy/f2py/src/fortranobject.c b/numpy/f2py/src/fortranobject.c
index 0209cb1be..8c8b4ae5d 100644
--- a/numpy/f2py/src/fortranobject.c
+++ b/numpy/f2py/src/fortranobject.c
@@ -370,7 +370,7 @@ fortran_setattr(PyFortranObject *fp, char *name, PyObject *v) {
Py_DECREF(arr);
}
} else return (fp->defs[i].func==NULL?-1:0);
- return 0; /* succesful */
+ return 0; /* successful */
}
if (fp->dict == NULL) {
fp->dict = PyDict_New();
diff --git a/numpy/lib/_datasource.py b/numpy/lib/_datasource.py
index c528de608..3affc5195 100644
--- a/numpy/lib/_datasource.py
+++ b/numpy/lib/_datasource.py
@@ -43,7 +43,7 @@ _open = open
# Using a class instead of a module-level dictionary
-# to reduce the inital 'import numpy' overhead by
+# to reduce the initial 'import numpy' overhead by
# deferring the import of bz2 and gzip until needed
# TODO: .zip support, .tar support?
diff --git a/numpy/lib/function_base.py b/numpy/lib/function_base.py
index 3c39d1a7b..8ee6a54dd 100644
--- a/numpy/lib/function_base.py
+++ b/numpy/lib/function_base.py
@@ -1607,7 +1607,7 @@ def gradient(f, *varargs, **kwargs):
Notes
-----
- Assuming that :math:`f\\in C^{3}` (i.e., :math:`f` has at least 3 continous
+ Assuming that :math:`f\\in C^{3}` (i.e., :math:`f` has at least 3 continuous
derivatives) and let be :math:`h_{*}` a non homogeneous stepsize, the
spacing the finite difference coefficients are computed by minimising
the consistency error :math:`\\eta_{i}`:
diff --git a/numpy/lib/index_tricks.py b/numpy/lib/index_tricks.py
index dc8eb1c4a..003774ce2 100644
--- a/numpy/lib/index_tricks.py
+++ b/numpy/lib/index_tricks.py
@@ -254,7 +254,7 @@ class AxisConcatenator(object):
if not isinstance(key, tuple):
key = (key,)
- # copy attributes, since they can be overriden in the first argument
+ # copy attributes, since they can be overridden in the first argument
trans1d = self.trans1d
ndmin = self.ndmin
matrix = self.matrix
diff --git a/numpy/lib/info.py b/numpy/lib/info.py
index e00406407..8815a52f0 100644
--- a/numpy/lib/info.py
+++ b/numpy/lib/info.py
@@ -103,7 +103,7 @@ roots Find roots of polynomial given coefficients
polyint Integrate polynomial
polyder Differentiate polynomial
polyadd Add polynomials
-polysub Substract polynomials
+polysub Subtract polynomials
polymul Multiply polynomials
polydiv Divide polynomials
polyval Evaluate polynomial at given argument
diff --git a/numpy/lib/shape_base.py b/numpy/lib/shape_base.py
index 588047952..830943e72 100644
--- a/numpy/lib/shape_base.py
+++ b/numpy/lib/shape_base.py
@@ -186,7 +186,7 @@ def apply_over_axes(func, a, axes):
Notes
------
This function is equivalent to tuple axis arguments to reorderable ufuncs
- with keepdims=True. Tuple axis arguments to ufuncs have been availabe since
+ with keepdims=True. Tuple axis arguments to ufuncs have been available since
version 1.7.0.
Examples
diff --git a/numpy/lib/tests/test_function_base.py b/numpy/lib/tests/test_function_base.py
index 7c07606f6..4f21e261f 100644
--- a/numpy/lib/tests/test_function_base.py
+++ b/numpy/lib/tests/test_function_base.py
@@ -2787,7 +2787,7 @@ class TestPercentile(TestCase):
interpolation="higher").shape, (3, 3, 5, 6))
def test_scalar_q(self):
- # test for no empty dimensions for compatiblity with old percentile
+ # test for no empty dimensions for compatibility with old percentile
x = np.arange(12).reshape(3, 4)
assert_equal(np.percentile(x, 50), 5.5)
self.assertTrue(np.isscalar(np.percentile(x, 50)))
@@ -2808,7 +2808,7 @@ class TestPercentile(TestCase):
assert_equal(np.percentile(x, 50, axis=1, out=out), r1)
assert_equal(out, r1)
- # test for no empty dimensions for compatiblity with old percentile
+ # test for no empty dimensions for compatibility with old percentile
x = np.arange(12).reshape(3, 4)
assert_equal(np.percentile(x, 50, interpolation='lower'), 5.)
self.assertTrue(np.isscalar(np.percentile(x, 50)))
diff --git a/numpy/lib/tests/test_stride_tricks.py b/numpy/lib/tests/test_stride_tricks.py
index 39a76c2f6..7dc3c4d24 100644
--- a/numpy/lib/tests/test_stride_tricks.py
+++ b/numpy/lib/tests/test_stride_tricks.py
@@ -407,7 +407,7 @@ def test_writeable():
_, result = broadcast_arrays(0, original)
assert_equal(result.flags.writeable, False)
- # regresssion test for GH6491
+ # regression test for GH6491
shape = (2,)
strides = [0]
tricky_array = as_strided(np.array(0), shape, strides)
diff --git a/numpy/lib/utils.py b/numpy/lib/utils.py
index 61aa5e33b..fad159c7e 100644
--- a/numpy/lib/utils.py
+++ b/numpy/lib/utils.py
@@ -339,7 +339,7 @@ def who(vardict=None):
#-----------------------------------------------------------------------------
-# NOTE: pydoc defines a help function which works simliarly to this
+# NOTE: pydoc defines a help function which works similarly to this
# except it uses a pager to take over the screen.
# combine name and arguments and split to multiple lines of width
diff --git a/numpy/linalg/umath_linalg.c.src b/numpy/linalg/umath_linalg.c.src
index 5fcc6d8ed..7a3a2ec3f 100644
--- a/numpy/linalg/umath_linalg.c.src
+++ b/numpy/linalg/umath_linalg.c.src
@@ -490,7 +490,7 @@ static void init_constants(void)
dst_row_strides: number of elements between different row. Matrix is
considered row-major
- dst_column_strides: number of elements between differnt columns in the
+ dst_column_strides: number of elements between different columns in the
destination buffer
rows: number of rows of the matrix
columns: number of columns of the matrix
diff --git a/numpy/ma/core.py b/numpy/ma/core.py
index bccb0bce1..d6b30ae2e 100644
--- a/numpy/ma/core.py
+++ b/numpy/ma/core.py
@@ -1954,7 +1954,7 @@ def masked_where(condition, a, copy=True):
(cshape, ashape) = (cond.shape, a.shape)
if cshape and cshape != ashape:
- raise IndexError("Inconsistant shape between the condition and the input"
+ raise IndexError("Inconsistent shape between the condition and the input"
" (got %s and %s)" % (cshape, ashape))
if hasattr(a, '_mask'):
cond = mask_or(cond, a._mask)
@@ -4655,7 +4655,7 @@ class MaskedArray(ndarray):
self._data.put(indices, values, mode=mode)
- # short circut if neither self nor values are masked
+ # short circuit if neither self nor values are masked
if self._mask is nomask and getmask(values) is nomask:
return
@@ -5889,7 +5889,7 @@ class MaskedArray(ndarray):
Parameters
----------
fill_value : scalar, optional
- Value used to fill in the masked values. Deafult is None, in which
+ Value used to fill in the masked values. Default is None, in which
case `MaskedArray.fill_value` is used.
order : {'C','F','A'}, optional
Order of the data item in the copy. Default is 'C'.
diff --git a/numpy/ma/tests/test_core.py b/numpy/ma/tests/test_core.py
index d37a561c2..c2b8d1403 100644
--- a/numpy/ma/tests/test_core.py
+++ b/numpy/ma/tests/test_core.py
@@ -4559,7 +4559,7 @@ class TestMaskedView(TestCase):
class TestOptionalArgs(TestCase):
def test_ndarrayfuncs(self):
- # test axis arg behaves the same as ndarray (including mutliple axes)
+ # test axis arg behaves the same as ndarray (including multiple axes)
d = np.arange(24.0).reshape((2,3,4))
m = np.zeros(24, dtype=bool).reshape((2,3,4))
diff --git a/numpy/ma/tests/test_deprecations.py b/numpy/ma/tests/test_deprecations.py
index 8eea42fae..24dd7cb8d 100644
--- a/numpy/ma/tests/test_deprecations.py
+++ b/numpy/ma/tests/test_deprecations.py
@@ -23,7 +23,7 @@ class TestArgsort(TestCase):
np.ma.core.MaskedArrayFutureWarning, argsort, arr_2d)
assert_equal(result, argsort(arr_2d, axis=None))
- # should be no warnings for explictly specifiying it
+ # should be no warnings for explicitly specifying it
argsort(arr_2d, axis=None)
argsort(arr_2d, axis=-1)
diff --git a/numpy/polynomial/legendre.py b/numpy/polynomial/legendre.py
index fa578360e..be8410b82 100644
--- a/numpy/polynomial/legendre.py
+++ b/numpy/polynomial/legendre.py
@@ -619,7 +619,7 @@ def legpow(c, pow, maxpower=16):
"""Raise a Legendre series to a power.
Returns the Legendre series `c` raised to the power `pow`. The
- arguement `c` is a sequence of coefficients ordered from low to high.
+ argument `c` is a sequence of coefficients ordered from low to high.
i.e., [1,2,3] is the series ``P_0 + 2*P_1 + 3*P_2.``
Parameters
diff --git a/numpy/testing/tests/test_decorators.py b/numpy/testing/tests/test_decorators.py
index 721c0ef7e..02cd9fb88 100644
--- a/numpy/testing/tests/test_decorators.py
+++ b/numpy/testing/tests/test_decorators.py
@@ -110,7 +110,7 @@ def test_skip_generators_hardcoded():
for j in g2(10):
pass
except KnownFailureException:
- raise Exception('Marked incorretly as known failure')
+ raise Exception('Marked incorrectly as known failure')
except DidntSkipException:
pass
@@ -144,7 +144,7 @@ def test_skip_generators_callable():
for j in g2(10):
pass
except KnownFailureException:
- raise Exception('Marked incorretly as known failure')
+ raise Exception('Marked incorrectly as known failure')
except DidntSkipException:
pass
diff --git a/numpy/tests/test_warnings.py b/numpy/tests/test_warnings.py
index dcae60a81..c5818d21c 100644
--- a/numpy/tests/test_warnings.py
+++ b/numpy/tests/test_warnings.py
@@ -1,6 +1,6 @@
"""
-Tests which scan for certain occurances in the code, they may not find
-all of these occurances but should catch almost all.
+Tests which scan for certain occurrences in the code, they may not find
+all of these occurrences but should catch almost all.
"""
diff --git a/pavement.py b/pavement.py
index 7ab43bb04..801e8c0c7 100644
--- a/pavement.py
+++ b/pavement.py
@@ -1,5 +1,5 @@
"""
-This paver file is intented to help with the release process as much as
+This paver file is intended to help with the release process as much as
possible. It relies on virtualenv to generate 'bootstrap' environments as
independent from the user system as possible (e.g. to make sure the sphinx doc
is built against the built numpy, not an installed one).
diff --git a/numpy/ma/extras.py b/numpy/ma/extras.py
index d55e0d1ea..d8ea3de8c 100644
--- a/numpy/ma/extras.py
+++ b/numpy/ma/extras.py
@@ -794,7 +794,7 @@ def _median(a, axis=None, out=None, overwrite_input=False):
def compress_nd(x, axis=None):
"""Supress slices from multiple dimensions which contain masked values.
Parameters
----------
@@ -803,10 +803,10 @@ def compress_nd(x, axis=None):
elements are masked, `x` is interpreted as a MaskedArray with `mask`
set to `nomask`.
axis : tuple of ints or int, optional
Which dimensions to supress slices from can be configured with this
parameter.
- - If axis is a tuple of ints, those are the axes to supress slices from.
- - If axis is an int, then that is the only axis to supress slices from.
+ - If axis is a tuple of ints, those are the axes to suppress slices from.
+ - If axis is an int, then that is the only axis to suppress slices from.
- If axis is None, all axis are selected.
Returns
@@ -794,7 +794,7 @@ def _median(a, axis=None, out=None, overwrite_input=False):
def compress_nd(x, axis=None):
- """Supress slices from multiple dimensions which contain masked values.
+ """Suppress slices from multiple dimensions which contain masked values.
Parameters
@@ -803,10 +803,10 @@ def compress_nd(x, axis=None):
set to `nomask`.
axis : tuple of ints or int, optional
- Which dimensions to supress slices from can be configured with this
+ Which dimensions to suppress slices from can be configured with this
parameter.